@@ -1,4 +1,4 @@
-`diff.fts` <- function (x, lag = 1, differences = 1, ...) 
+diff.fts <- function (x, lag = 1, differences = 1, ...) 
 {
     if (class(x)[1] == "fts"|class(x)[1] == "sfts"){
         x$y <- t(diff(t(x$y), lag, differences, ...))
