@@ -1,4 +1,4 @@
-extract.x = function (data, xorder) 
+extract.x <- function(data, xorder) 
 {
     x = data$x
     y = data$y
@@ -17,4 +17,4 @@ extract.x = function (data, xorder)
     rownames(ftsdata$y) = as.character(xorder)
     class(ftsdata) = class(data)
     return(ftsdata)
-}
\ No newline at end of file
+}
