@@ -1,4 +1,4 @@
-func.var = function (functions) 
+func.var <- function(functions) 
 {
     nrow = dim(functions)[1]
     (nrow - 1) * apply(functions, 2, var)/nrow
